@@ -1,4 +1,4 @@
-#line 1 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* -*- c -*-
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -172,7 +172,7 @@ struct hash_ent
 
 
 
-#line 177 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 177 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct callback_list do_debug_callbacks;
 struct timeval current_time;
 struct timeval next_timeout;
@@ -457,31 +457,31 @@ static void copy_selectors(struct active_selectors *to,
 #undef class_Backend_defined
 #define class_Backend_defined
 struct program *Backend_program=0;
-#line 459 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 459 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* Provide a unique count to be able to tell backends apart with _sprintf. */
   static int unused_id = 0;
   
 #undef var_id_Backend_defined
 #define var_id_Backend_defined
-#line 463 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 463 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /*
    * Backend callbacks
    */
   
 #undef var_backend_callbacks_Backend_defined
 #define var_backend_callbacks_Backend_defined
-#line 468 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 468 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* Thread currently executing in the backend. */
 #ifdef PIKE_THREADS
   
 #undef var_exec_thread_Backend_defined
 #define var_exec_thread_Backend_defined
-#line 471 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 471 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 #else
   
 #undef var_exec_thread_Backend_defined_2
 #define var_exec_thread_Backend_defined_2
-#line 472 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 472 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* 1 if inside the backend. */
 #endif
 
@@ -491,7 +491,7 @@ struct program *Backend_program=0;
   
 #undef var_wakeup_pipe_Backend_defined
 #define var_wakeup_pipe_Backend_defined
-#line 480 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 480 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /*
    * FD callback data
    */
@@ -501,7 +501,7 @@ struct program *Backend_program=0;
 
 #undef var_fds_size_Backend_defined
 #define var_fds_size_Backend_defined
-#line 486 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 486 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* 
    * POLL/SELECT fd sets
    */
@@ -511,24 +511,24 @@ struct program *Backend_program=0;
 
 #undef var_active_set_Backend_defined
 #define var_active_set_Backend_defined
-#line 492 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 492 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /*
    * CALL OUT variables
    */
   
 #undef var_num_pending_calls_Backend_defined
 #define var_num_pending_calls_Backend_defined
-#line 495 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 495 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* no of busy pointers in buffer */
   
 #undef var_call_buffer_Backend_defined
 #define var_call_buffer_Backend_defined
-#line 496 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 496 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* pointer to buffer */
   
 #undef var_call_buffer_size_Backend_defined
 #define var_call_buffer_size_Backend_defined
-#line 497 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 497 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* no of pointers in buffer */
   
   
@@ -540,7 +540,7 @@ struct program *Backend_program=0;
 
 #undef var_call_hash_Backend_defined
 #define var_call_hash_Backend_defined
-#line 503 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 503 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* Should really exist only in PIKE_DEBUG, but 
    * #ifdefs on the last cvar confuses precompile.pike.
    *	/grubba 2001-03-12
@@ -550,7 +550,7 @@ struct program *Backend_program=0;
   
 #undef var_inside_call_out_Backend_defined
 #define var_inside_call_out_Backend_defined
-#line 510 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 510 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 #endif
 
   
@@ -569,12 +569,12 @@ static ptrdiff_t Backend_storage_offset;
 struct Backend_struct {
 
 #ifdef var_id_Backend_defined
-#line 461 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 461 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int id;
 #endif /* var_id_Backend_defined */
 
 #ifdef var_backend_callbacks_Backend_defined
-#line 466 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 466 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct callback_list backend_callbacks;
 #endif /* var_backend_callbacks_Backend_defined */
 
@@ -583,71 +583,71 @@ struct thread_state *exec_thread;
 #endif /* var_exec_thread_Backend_defined */
 
 #ifdef var_exec_thread_Backend_defined_2
-#line 472 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 472 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int exec_thread;
 #endif /* var_exec_thread_Backend_defined_2 */
 
 #ifdef var_wakeup_pipe_Backend_defined
-#line 478 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 478 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int wakeup_pipe[2];
 #endif /* var_wakeup_pipe_Backend_defined */
 
 #ifdef var_fds_Backend_defined
-#line 483 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 483 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct fd_datum *fds;
 #endif /* var_fds_Backend_defined */
 
 #ifdef var_fds_size_Backend_defined
-#line 484 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 484 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int fds_size;
 #endif /* var_fds_size_Backend_defined */
 
 #ifdef var_set_Backend_defined
-#line 489 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 489 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct selectors set;
 #endif /* var_set_Backend_defined */
 
 #ifdef var_active_set_Backend_defined
-#line 490 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 490 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct active_selectors active_set;
 #endif /* var_active_set_Backend_defined */
 
 #ifdef var_num_pending_calls_Backend_defined
-#line 495 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 495 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int num_pending_calls;
 #endif /* var_num_pending_calls_Backend_defined */
 
 #ifdef var_call_buffer_Backend_defined
-#line 496 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 496 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 call_out **call_buffer;
 #endif /* var_call_buffer_Backend_defined */
 
 #ifdef var_call_buffer_size_Backend_defined
-#line 497 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 497 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int call_buffer_size;
 #endif /* var_call_buffer_size_Backend_defined */
 
 #ifdef var_hash_size_Backend_defined
-#line 499 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 499 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 unsigned int hash_size;
 #endif /* var_hash_size_Backend_defined */
 
 #ifdef var_hash_order_Backend_defined
-#line 500 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 500 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 unsigned int hash_order;
 #endif /* var_hash_order_Backend_defined */
 
 #ifdef var_call_hash_Backend_defined
-#line 501 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 501 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct hash_ent *call_hash;
 #endif /* var_call_hash_Backend_defined */
 
 #ifdef var_inside_call_out_Backend_defined
-#line 509 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 509 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 int inside_call_out;
 #endif /* var_inside_call_out_Backend_defined */
 };
-#line 513 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 513 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /*
    * Call out defines
    */
@@ -1597,17 +1597,17 @@ int inside_call_out;
    */
   #define f_Backend_cq__backtick_28_29_defined
 void f_Backend_cq__backtick_28_29(INT32 args) {
-#line 1460 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1460 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct svalue * sleep_time;
-#line 1460 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1460 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args > 1) wrong_number_of_args_error("`()",args,1);
 if(args > 0) { 
-#line 1460 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1460 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 sleep_time=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 }else{
 sleep_time=0;
 }
-#line 1461 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1461 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 {
     struct timeval timeout;
 
@@ -1641,9 +1641,9 @@ sleep_time=0;
    */
   #define f_Backend_executing_thread_defined
 void f_Backend_executing_thread(INT32 args) {
-#line 1491 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1491 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 0) wrong_number_of_args_error("executing_thread",args,0);
-#line 1494 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1494 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 {
     pop_n_elems (args);
 #ifdef PIKE_THREADS
@@ -1662,13 +1662,13 @@ if(args != 0) wrong_number_of_args_error("executing_thread",args,0);
    */
   #define f_Backend_add_file_defined
 void f_Backend_add_file(INT32 args) {
-#line 1509 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1509 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct object * f;
-#line 1509 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1509 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 1) wrong_number_of_args_error("add_file",args,1);
-#line 1509 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1509 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(Pike_sp[0-1].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("add_file",1,"object");
-#line 1509 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1509 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 debug_malloc_pass(f=Pike_sp[0-1].u.object);
 {
       int fd=fd_from_object(f);
@@ -1712,7 +1712,7 @@ debug_malloc_pass(f=Pike_sp[0-1].u.object);
 
 
   }
-#line 1551 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1551 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* CALL OUT */
 
 #ifdef PIKE_DEBUG
@@ -2049,28 +2049,28 @@ debug_malloc_pass(f=Pike_sp[0-1].u.object);
  */
    #define f_Backend_call_out_defined
 void f_Backend_call_out(INT32 args) {
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct svalue * f;
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct svalue * t;
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct svalue * rest;
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args < 2) wrong_number_of_args_error("call_out",args,2);
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 f=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 t=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if (args > 2) {
   INT32 argcnt = 0;
   do {
     dmalloc_touch_svalue(Pike_sp+2+argcnt-args);
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   } while (++argcnt < args-2);
   rest=Pike_sp+2-args;
 } else rest=0;
-#line 1886 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1886 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 {
        struct svalue tmp;
        struct array *v;
@@ -2090,7 +2090,7 @@ if (args > 2) {
      }
 
    }
-#line 1904 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1904 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* Assumes current_time is correct on entry. */
    int backend_do_call_outs(struct Backend_struct *me)
      {
@@ -2222,7 +2222,7 @@ if (args > 2) {
  */
    #define f_Backend_cq__do_call_outs_defined
 void f_Backend_cq__do_call_outs(INT32 args) {
-#line 2033 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2033 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 0) wrong_number_of_args_error("_do_call_outs",args,0);
 {
        GETTIMEOFDAY(&current_time);
@@ -2252,11 +2252,11 @@ if(args != 0) wrong_number_of_args_error("_do_call_outs",args,0);
  */
    #define f_Backend_find_call_out_defined
 void f_Backend_find_call_out(INT32 args) {
-#line 2059 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2059 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct svalue * f;
-#line 2059 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2059 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 1) wrong_number_of_args_error("find_call_out",args,1);
-#line 2059 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2059 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 f=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
 {
        struct Backend_struct *me=THIS;
@@ -2299,11 +2299,11 @@ f=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
  */
    #define f_Backend_remove_call_out_defined
 void f_Backend_remove_call_out(INT32 args) {
-#line 2098 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2098 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct svalue * f;
-#line 2098 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2098 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 1) wrong_number_of_args_error("remove_call_out",args,1);
-#line 2098 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2098 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 f=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
 {
        struct Backend_struct *me=THIS;
@@ -2342,7 +2342,7 @@ f=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
      }
 
 }
-#line 2135 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2135 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* return an array containing info about all call outs:
  * ({  ({ delay, caller, function, args, ... }), ... })
  */
@@ -2409,11 +2409,11 @@ f=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
  */
    #define f_Backend_call_out_info_defined
 void f_Backend_call_out_info(INT32 args) {
-#line 2199 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2199 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 0) wrong_number_of_args_error("call_out_info",args,0);
 {
        do { struct array * ret_=(backend_get_all_call_outs(THIS));  push_array(ret_); return; }while(0);
-#line 2202 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2202 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 }
 
    }
@@ -2424,28 +2424,28 @@ if(args != 0) wrong_number_of_args_error("call_out_info",args,0);
     */
    #define f_Backend_id_defined
 void f_Backend_id(INT32 args) {
-#line 2209 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2209 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 0) wrong_number_of_args_error("id",args,0);
 {
      do { INT_TYPE ret_=((THIS->id));  push_int(ret_); return; }while(0);
-#line 2212 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2212 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 }
 
    }
 #define f_Backend_cq__sprintf_defined
 void f_Backend_cq__sprintf(INT32 args) {
-#line 2214 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2214 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 INT_TYPE type;
-#line 2214 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2214 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 struct mapping * flags;
-#line 2214 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2214 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(args != 2) wrong_number_of_args_error("_sprintf",args,2);
-#line 2214 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2214 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(Pike_sp[0-2].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("_sprintf",1,"int");
 type=Pike_sp[0-2].u.integer;
-#line 2214 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2214 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 if(Pike_sp[1-2].type != PIKE_T_MAPPING) SIMPLE_BAD_ARG_ERROR("_sprintf",2,"mapping(mixed:mixed)");
-#line 2214 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2214 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 debug_malloc_pass(flags=Pike_sp[1-2].u.mapping);
 {
      if (type == 'O') {
@@ -2461,7 +2461,7 @@ debug_malloc_pass(flags=Pike_sp[1-2].u.mapping);
    }
 
   }
-#line 2228 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2228 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 extern int pike_make_pipe(int *);
 
 #ifdef PIKE_DEBUG
@@ -2472,7 +2472,7 @@ extern int pike_make_pipe(int *);
 #undef Backend_event_handler_defined
 #define Backend_event_handler_defined
 static void gc_check_Backend_struct(void)
-#line 2232 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2232 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 {
       struct Backend_struct *me =
 	(struct Backend_struct *) Pike_fp->current_storage;
@@ -2497,7 +2497,7 @@ static void gc_check_Backend_struct(void)
 #undef Backend_event_handler_defined
 #define Backend_event_handler_defined
 static void init_Backend_struct(void)
-#line 2250 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2250 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 {
       THIS->id = unused_id++;
 
@@ -2569,7 +2569,7 @@ static void init_Backend_struct(void)
 #undef Backend_event_handler_defined
 #define Backend_event_handler_defined
 static void exit_Backend_struct(void)
-#line 2315 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2315 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 {
       struct Backend_struct *me=THIS;
       int e;
@@ -2679,7 +2679,7 @@ static void Backend_event_handler(int ev) {
  *!   @[Pike.Backend()->call_out_info()]
  */
 
-#line 2402 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2402 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 /* This doesn't need to be here */
 PMOD_EXPORT int write_to_stderr(char *a, size_t len)
 {
@@ -2815,55 +2815,55 @@ void init_backend(void)
 #endif /* Backend_event_handler_defined */
 
 #ifdef f_Backend_cq__backtick_28_29_defined
-#line 1460 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1460 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("`()", f_Backend_cq__backtick_28_29, tFunc(tOr3(tVoid,tFloat,"\10\0\0\0\0\0\0\0\0"),tOr(tFloat,"\10\0\0\0\0\0\0\0\0")), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_cq__backtick_28_29_defined */
 
 #ifdef f_Backend_executing_thread_defined
-#line 1491 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1491 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("executing_thread", f_Backend_executing_thread, tFunc(tNone,tOr(tObj,"\10\0\0\0\0\0\0\0\1")), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_executing_thread_defined */
 
 #ifdef f_Backend_add_file_defined
-#line 1509 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1509 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("add_file", f_Backend_add_file, tFunc(tObj,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_add_file_defined */
 
 #ifdef f_Backend_call_out_defined
-#line 1885 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 1885 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("call_out", f_Backend_call_out, tFuncV(tMix tOr("\10\200\0\0\0\177\377\377\377",tFloat),tMix,tMix), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_call_out_defined */
 
 #ifdef f_Backend_cq__do_call_outs_defined
-#line 2033 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2033 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("_do_call_outs", f_Backend_cq__do_call_outs, tFunc(tNone,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_cq__do_call_outs_defined */
 
 #ifdef f_Backend_find_call_out_defined
-#line 2059 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2059 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("find_call_out", f_Backend_find_call_out, tFunc(tOr(tFuncV(tNone,tMix,tAny),tMix),"\10\200\0\0\0\177\377\377\377"), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_find_call_out_defined */
 
 #ifdef f_Backend_remove_call_out_defined
-#line 2098 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2098 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("remove_call_out", f_Backend_remove_call_out, tFunc(tOr(tFuncV(tNone,tMix,tAny),tMix),"\10\200\0\0\0\177\377\377\377"), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_remove_call_out_defined */
 
 #ifdef f_Backend_call_out_info_defined
-#line 2199 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2199 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("call_out_info", f_Backend_call_out_info, tFunc(tNone,tArr(tArray)), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_call_out_info_defined */
 
 #ifdef f_Backend_id_defined
-#line 2209 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2209 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
   ADD_FUNCTION2("id", f_Backend_id, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Backend_id_defined */
@@ -2876,7 +2876,7 @@ void init_backend(void)
   add_program_constant("Backend",Backend_program,0);
 
 #endif /* class_Backend_defined */
-#line 2515 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2515 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 ;
   {
     struct object *o=clone_object(Backend_program,0);
@@ -2897,7 +2897,7 @@ void exit_backend()
   }
 
 #endif /* class_Backend_defined */
-#line 2527 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
+#line 2527 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/backend.cmod"
 ;
   default_backend=0;
   free_all_call_out_s_blocks();
