@@ -1,4 +1,4 @@
-#line 1 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 1 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 /*
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -258,7 +258,7 @@ OPCODE1_TAIL(F_MARK_AND_STRING, "mark & string", 0, {
     print_return_value();
   };
 })
-#line 252 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 252 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE1(F_STRING, "string", 0, {
     copy_shared_string(Pike_sp->u.string,Pike_fp->context.prog->strings[arg1]);
     Pike_sp->type=PIKE_T_STRING;
@@ -266,7 +266,7 @@ OPCODE1(F_STRING, "string", 0, {
     Pike_sp++;
     print_return_value();
   })
-#line 259 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 259 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
 
@@ -360,7 +360,7 @@ OPCODE1_TAIL(F_MARK_AND_GLOBAL, "mark & global", 0, {
     print_return_value();
   };
 })
-#line 344 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 344 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE1(F_GLOBAL, "global", 0, {
     low_object_index_no_free(Pike_sp,
 			     Pike_fp->current_object,
@@ -368,7 +368,7 @@ OPCODE1(F_GLOBAL, "global", 0, {
     Pike_sp++;
     print_return_value();
   })
-#line 351 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 351 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
 OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", 0, {
@@ -402,7 +402,7 @@ OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", 0, {
     print_return_value();
   };
 })
-#line 356 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 356 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE2(F_EXTERNAL,"external", 0, {
     struct external_variable_context loc;
 
@@ -430,7 +430,7 @@ OPCODE2(F_EXTERNAL,"external", 0, {
     }
     print_return_value();
   })
-#line 383 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 383 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
 
@@ -1038,18 +1038,18 @@ OPCODE0_TAIL(F_MARK2, "mark mark", 0, {
     };
   };
 })
-#line 983 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 983 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE0_TAIL(F_SYNCH_MARK, "synch mark", 0, {
 
     {
       *(Pike_mark_sp++)=Pike_sp;
     };
   })
-#line 985 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 985 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE0(F_MARK, "mark", 0, {
       *(Pike_mark_sp++)=Pike_sp;
     })
-#line 989 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 989 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
 OPCODE1(F_MARK_X, "mark Pike_sp-X", 0, {
@@ -1086,7 +1086,7 @@ OPCODE0_TAIL(F_CLEANUP_SYNCH_MARK, "cleanup synch mark", 0, {
     }
   };
 })
-#line 1007 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 1007 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", 0, {
     if (d_flag) {
       if (Pike_mark_sp <= Pike_interpreter.mark_stack) {
@@ -1104,7 +1104,7 @@ OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", 0, {
       }
     }
   })
-#line 1024 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 1024 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
 OPCODE0(F_CLEAR_STRING_SUBTYPE, "clear string subtype", 0, {
@@ -1138,7 +1138,7 @@ OPCODE2_BRANCH(F_BRANCH_IF_NOT_LOCAL_ARROW, "branch if !local->x", 0, {
     pop_stack();
   };
 })
-#line 1047 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 1047 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", 0, {
     if(!UNSAFE_IS_ZERO(Pike_sp-1))
     {
@@ -1148,7 +1148,7 @@ OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", 0, {
     }
     pop_stack();
   })
-#line 1056 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 1056 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
       
@@ -2317,11 +2317,11 @@ OPCODE1_JUMP(F_COND_RECUR, "recur if not overloaded", 0, {
     DO_RECUR(0);
   };
 })
-#line 2220 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 2220 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 OPCODE0_TAILJUMP(F_RECUR, "recur", 0, {
     DO_RECUR(0);
   })
-#line 2223 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
+#line 2223 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/interpret_functions.h"
 
 
 /* Ugly code duplication */
