@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: mysql.c,v 1.67 2004/04/19 14:14:28 grubba Exp $
+|| $Id: mysql.c,v 1.70 2005/08/09 16:30:34 grubba Exp $
 */
 
 /*
@@ -94,7 +94,7 @@
  * Globals
  */
 
-RCSID("$Id: mysql.c,v 1.67 2004/04/19 14:14:28 grubba Exp $");
+RCSID("$Id: mysql.c,v 1.70 2005/08/09 16:30:34 grubba Exp $");
 
 /*! @module Mysql
  *!
@@ -277,12 +277,12 @@ static void pike_mysql_set_options(struct mapping *options)
   if ((val = simple_mapping_string_lookup(options, "mysql_local_infile")) &&
       (val->type == T_INT)) {
     unsigned int allowed = (unsigned int)val->u.integer;
-    mysql_options(PIKE_MYSQL->mysql, MYSQL_OPT_CONNECT_TIMEOUT,
+    mysql_options(PIKE_MYSQL->mysql, MYSQL_OPT_LOCAL_INFILE,
 		  (char *)&allowed);
   } else {
     /* Default to not allowed */
     unsigned int allowed = 0;
-    mysql_options(PIKE_MYSQL->mysql, MYSQL_OPT_CONNECT_TIMEOUT,
+    mysql_options(PIKE_MYSQL->mysql, MYSQL_OPT_LOCAL_INFILE,
 		  (char *)&allowed);    
   }
 #endif /* MYSQL_OPT_LOCAL_INFILE */
@@ -493,12 +493,12 @@ static void pike_mysql_reconnect(void)
  */
 static void f_create(INT32 args)
 {
-#ifdef HAVE_MYSQL_OPTIONS
+#if defined(HAVE_MYSQL_OPTIONS) && defined(HAVE_MYSQL_OPT_LOCAL_INFILE)
   /* Default to not allowed */
   unsigned int allowed = 0;
-  mysql_options(PIKE_MYSQL->mysql, MYSQL_OPT_CONNECT_TIMEOUT,
+  mysql_options(PIKE_MYSQL->mysql, MYSQL_OPT_LOCAL_INFILE,
 		(char *)&allowed);    
-#endif /* HAVE_MYSQL_OPTIONS */
+#endif /* HAVE_MYSQL_OPTIONS && HAVE_MYSQL_OPT_LOCAL_INFILE */
 
   if (args >= 1) {
     CHECK_8BIT_NONBINARY_STRING ("Mysql.mysql->create", 1);
@@ -1004,7 +1004,12 @@ static void f_shutdown(INT32 args)
   if (socket) {
     MYSQL_ALLOW();
   
+#ifdef HAVE_SHUTDOWN_DEFAULT
+    /* Mysql 4.1.3 added an extra shutdown_level argument. */
+    tmp = mysql_shutdown(socket, SHUTDOWN_DEFAULT);
+#else /* !HAVE_SHUTDOWN_DEFAULT */
     tmp = mysql_shutdown(socket);
+#endif /* HAVE_SHUTDOWN_DEFAULT */
 
     MYSQL_DISALLOW();
   }
@@ -1016,7 +1021,12 @@ static void f_shutdown(INT32 args)
 
     MYSQL_ALLOW();
   
+#ifdef HAVE_SHUTDOWN_DEFAULT
+    /* Mysql 4.1.3 added an extra shutdown_level argument. */
+    tmp = mysql_shutdown(socket, SHUTDOWN_DEFAULT);
+#else /* !HAVE_SHUTDOWN_DEFAULT */
     tmp = mysql_shutdown(socket);
+#endif /* HAVE_SHUTDOWN_DEFAULT */
 
     MYSQL_DISALLOW();
   }
