@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: efuns.c,v 1.121 2004/10/04 08:13:27 grubba Exp $
+|| $Id: efuns.c,v 1.126 2005/10/24 16:30:51 grubba Exp $
 */
 
 #include "global.h"
@@ -26,7 +26,7 @@
 #include "file_machine.h"
 #include "file.h"
 
-RCSID("$Id: efuns.c,v 1.121 2004/10/04 08:13:27 grubba Exp $");
+RCSID("$Id: efuns.c,v 1.126 2005/10/24 16:30:51 grubba Exp $");
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -188,12 +188,14 @@ void f_file_stat(INT32 args)
   }
 
   THREADS_ALLOW_UID();
+  do {
 #ifdef HAVE_LSTAT
-  if(l)
-    i=fd_lstat(str->str, &st);
-  else
+    if(l)
+      i=fd_lstat(str->str, &st);
+    else
 #endif
-    i=fd_stat(str->str, &st);
+      i=fd_stat(str->str, &st);
+  } while ((i == -1) && (errno == EINTR));
 
   THREADS_DISALLOW_UID();
   pop_n_elems(args);
@@ -801,6 +803,27 @@ void f_mkdir(INT32 args)
 #define HAVE_READDIR_R
 #endif
 
+#if defined(_REENTRANT) && defined(HAVE_READDIR_R)
+
+#ifdef _PC_NAME_MAX
+#ifdef HAVE_FPATHCONF
+
+#ifdef HAVE_FDOPENDIR
+#define USE_FDOPENDIR
+#define USE_FPATHCONF
+#elif defined(HAVE_DIRFD)
+#define USE_FPATHCONF
+#endif
+
+#endif /* HAVE_FPATHCONF */
+
+#if defined(HAVE_PATHCONF) && !defined(USE_FPATHCONF)
+#define USE_PATHCONF
+#endif
+#endif /* _PC_NAME_MAX */
+
+#endif /* _REENTRANT && HAVE_READDIR_R */
+
 /*! @decl array(string) get_dir(string dirname)
  *!
  *! Returns an array of all filenames in the directory @[dirname], or
@@ -812,7 +835,13 @@ void f_mkdir(INT32 args)
 void f_get_dir(INT32 args)
 {
   struct svalue *save_sp=sp;
-  DIR *dir;
+#ifdef USE_FDOPENDIR
+  int dir_fd;
+#endif
+  DIR *dir = NULL;
+#ifdef HAVE_READDIR_R
+  ptrdiff_t name_max = -1;
+#endif
   struct dirent *d;
   struct array *a=0;
   struct pike_string *str;
@@ -831,7 +860,26 @@ void f_get_dir(INT32 args)
 
 #if defined(_REENTRANT) && defined(HAVE_READDIR_R)
   THREADS_ALLOW_UID();
+#ifdef USE_FDOPENDIR
+  dir_fd = open(str->str, O_RDONLY);
+  if (dir_fd != -1) {
+#ifdef USE_FPATHCONF
+    name_max = fpathconf(dir_fd, _PC_NAME_MAX);
+#endif /* USE_FPATHCONF */
+    dir = fdopendir(dir_fd);
+    if (!dir) close(dir_fd);
+  }
+#else
   dir = opendir(str->str);
+#ifdef USE_FPATHCONF
+  if (dir) {
+    name_max = fpathconf(dirfd(dir), _PC_NAME_MAX);
+  }
+#endif
+#endif /* !HAVE_FDOPENDIR */
+#ifdef USE_PATHCONF
+  name_max = pathconf(str->str, _PC_NAME_MAX);
+#endif
   THREADS_DISALLOW_UID();
   if(dir)
   {
@@ -841,18 +889,14 @@ void f_get_dir(INT32 args)
     ptrdiff_t lens[FPR];
     struct dirent *tmp;
 
-    if (!(tmp =
-#if defined(HAVE_SOLARIS_READDIR_R) || defined(_PC_NAME_MAX)
-	  malloc(sizeof(struct dirent) + 
-		 ((pathconf(str->str, _PC_NAME_MAX) < 1024)?1024:
-		  pathconf(str->str, _PC_NAME_MAX)) + 1)
-#else
 #ifndef NAME_MAX
 #define NAME_MAX 1024
 #endif
-	  malloc(sizeof(struct dirent) + NAME_MAX+ 1024 + 1)
-#endif /* HAVE_SOLARIS_READDIR_R */
-      )) {
+    if (name_max < NAME_MAX)
+      name_max = NAME_MAX;
+    if (name_max < 1024) name_max = 1024;
+
+    if (!(tmp = malloc(sizeof(struct dirent) + name_max + 1))) {
       closedir(dir);
       Pike_error("get_dir(): Out of memory\n");
     }
