@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: sprintf.c,v 1.102 2003/10/16 16:20:57 grubba Exp $
+|| $Id: sprintf.c,v 1.103 2005/09/09 16:05:13 mast Exp $
 */
 
 /* TODO: use ONERROR to cleanup fsp */
@@ -286,7 +286,7 @@
  *!   @[lfun::_sprintf()]
  */
 #include "global.h"
-RCSID("$Id: sprintf.c,v 1.102 2003/10/16 16:20:57 grubba Exp $");
+RCSID("$Id: sprintf.c,v 1.103 2005/09/09 16:05:13 mast Exp $");
 #include "pike_error.h"
 #include "array.h"
 #include "svalue.h"
@@ -1027,6 +1027,8 @@ static void low_pike_sprintf(struct format_stack *fs,
   PCHARP a,begin;
   PCHARP format_end=ADD_PCHARP(format,format_len);
 
+  check_c_stack (250);
+
   start=fs->fsp;
   for(a=format;COMPARE_PCHARP(a,<,format_end);INC_PCHARP(a,1))
   {
@@ -1644,19 +1646,28 @@ dynbuf_string pike_sprintf(char *format,struct svalue *argp,int num_arg)
 }
  */
 
+struct f_sprintf_data
+{
+  struct string_builder r;
+  struct format_stack *fs;
+};
+
+static void free_f_sprintf_data (struct f_sprintf_data *d)
+{
+  free_string_builder (&d->r);
+  free_sprintf_strings (d->fs);
+  free (d->fs);
+}
+
 /* The efun */
 void f_sprintf(INT32 num_arg)
 {
-  ONERROR err_string_builder, err_format_stack;
+  ONERROR uwp;
   struct pike_string *ret;
   struct svalue *argp;
-  struct string_builder r;
-
-  struct format_stack fs;
+  struct f_sprintf_data d;
 
   argp=sp-num_arg;
-  
-  fs.fsp = fs.format_info_stack-1;
 
   if(argp[0].type != T_STRING) {
     if (argp[0].type == T_OBJECT) {
@@ -1677,19 +1688,21 @@ void f_sprintf(INT32 num_arg)
   }
 /*  fprintf(stderr,"SPRINTF: %s\n",argp->u.string->str); */
 
-  init_string_builder(&r,0);
-  SET_ONERROR(err_format_stack, free_sprintf_strings, &fs);
-  SET_ONERROR(err_string_builder, free_string_builder, &r);
-  low_pike_sprintf(&fs,
-		   &r,
+  d.fs = ALLOC_STRUCT (format_stack);
+  d.fs->fsp = d.fs->format_info_stack-1;
+
+  init_string_builder(&d.r,0);
+  SET_ONERROR(uwp, free_f_sprintf_data, &d);
+  low_pike_sprintf(d.fs,
+		   &d.r,
 		   MKPCHARP_STR(argp->u.string),
 		   argp->u.string->len,
 		   argp+1,
 		   num_arg-1,
 		   0);
-  UNSET_ONERROR(err_string_builder);
-  UNSET_ONERROR(err_format_stack);
-  ret=finish_string_builder(&r);
+  UNSET_ONERROR(uwp);
+  ret=finish_string_builder(&d.r);
+  free (d.fs);
 
   pop_n_elems(num_arg);
   push_string(ret);
