@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: opcodes.c,v 1.131 2004/09/20 12:11:25 mast Exp $
+|| $Id: opcodes.c,v 1.132 2005/08/08 09:44:06 jonasw Exp $
 */
 
 #include "global.h"
@@ -30,7 +30,7 @@
 
 #define sp Pike_sp
 
-RCSID("$Id: opcodes.c,v 1.131 2004/09/20 12:11:25 mast Exp $");
+RCSID("$Id: opcodes.c,v 1.132 2005/08/08 09:44:06 jonasw Exp $");
 
 void index_no_free(struct svalue *to,struct svalue *what,struct svalue *ind)
 {
@@ -1497,22 +1497,30 @@ CHAROPT2(								 \
 	      return matches;						 \
 	    }								 \
 									 \
-	    sval.type=T_STRING;						 \
-	    DO_IF_CHECKER(sval.subtype=0);				 \
-	    sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
-                                      INPUT_SHIFT)(input+eye,		 \
-						   field_length);	 \
+	    if (no_assign) {						 \
+	      no_assign = 2;						 \
+	    } else {							 \
+	      sval.type=T_STRING;					 \
+	      DO_IF_CHECKER(sval.subtype=0);				 \
+	      sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
+					INPUT_SHIFT)(input+eye,		 \
+						     field_length);	 \
+	    }								 \
 	    eye+=field_length;						 \
 	    break;							 \
 	  }								 \
 									 \
 	  if(cnt+1>=match_len)						 \
 	  {								 \
-	    sval.type=T_STRING;						 \
-	    DO_IF_CHECKER(sval.subtype=0);				 \
-	    sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
-				      INPUT_SHIFT)(input+eye,		 \
-						   input_len-eye);	 \
+	    if (no_assign) {						 \
+	      no_assign = 2;						 \
+	    } else {							 \
+	      sval.type=T_STRING;					 \
+	      DO_IF_CHECKER(sval.subtype=0);				 \
+	      sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
+					INPUT_SHIFT)(input+eye,		 \
+						     input_len-eye);	 \
+	    }								 \
 	    eye=input_len;						 \
 	    break;							 \
 	  }else{							 \
@@ -1611,11 +1619,15 @@ CHAROPT2(								 \
 	    end_str_end=match+e;					 \
 									 \
 	    if (end_str_end == end_str_start) {				 \
-	      sval.type=T_STRING;					 \
-	      DO_IF_CHECKER(sval.subtype=0);				 \
-	      sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
-	      				INPUT_SHIFT)(input+eye,		 \
-	      					     input_len-eye);	 \
+	      if (no_assign) {						 \
+		no_assign = 2;						 \
+	      } else {							 \
+		sval.type=T_STRING;					 \
+		DO_IF_CHECKER(sval.subtype=0);				 \
+		sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
+					  INPUT_SHIFT)(input+eye,	 \
+						       input_len-eye);	 \
+	      }								 \
 	      eye=input_len;						 \
 	      break;							 \
 	    } else if(!contains_percent_percent)			 \
@@ -1656,11 +1668,15 @@ CHAROPT2(								 \
 	      new_eye=p2-input;						 \
 	    }								 \
 									 \
-	    sval.type=T_STRING;						 \
-	    DO_IF_CHECKER(sval.subtype=0);				 \
-	    sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
-				      INPUT_SHIFT)(input+start,		 \
-						   eye-start);		 \
+	    if (no_assign) {						 \
+	      no_assign = 2;						 \
+	    } else {							 \
+	      sval.type=T_STRING;					 \
+	      DO_IF_CHECKER(sval.subtype=0);				 \
+	      sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
+					INPUT_SHIFT)(input+start,	 \
+						     eye-start);	 \
+	    }								 \
 									 \
 	    cnt=end_str_end-match-1;					 \
 	    eye=new_eye;						 \
@@ -1697,10 +1713,14 @@ CHAROPT2(								 \
 )									 \
 	  }								 \
           if(set.a) { free_array(set.a); set.a=0; }			 \
-	  sval.type=T_STRING;						 \
-	  DO_IF_CHECKER(sval.subtype=0);				 \
-	  sval.u.string=PIKE_CONCAT(make_shared_binary_string,		 \
-				    INPUT_SHIFT)(input+e,eye-e);	 \
+	  if (no_assign) {						 \
+	    no_assign = 2;						 \
+	  } else {							 \
+	    sval.type=T_STRING;						 \
+	    DO_IF_CHECKER(sval.subtype=0);				 \
+	    sval.u.string=PIKE_CONCAT(make_shared_binary_string,	 \
+				      INPUT_SHIFT)(input+e,eye-e);	 \
+	  }								 \
 	  break;							 \
 									 \
 	case 'n':							 \
@@ -1710,7 +1730,7 @@ CHAROPT2(								 \
 	  break;							 \
 									 \
 	default:							 \
-	  Pike_error("Unknown sscanf token %%%c(0x%02x)\n",			 \
+	  Pike_error("Unknown sscanf token %%%c(0x%02x)\n",		 \
 		match[cnt], match[cnt]);				 \
       }									 \
       break;								 \
@@ -1719,8 +1739,9 @@ CHAROPT2(								 \
 									 \
     if(no_assign)							 \
     {									 \
-      free_svalue(&sval);						 \
-    }else{								 \
+      if (no_assign == 1)						 \
+	free_svalue(&sval);						 \
+    } else {								 \
       check_stack(1);							 \
       *sp++=sval;							 \
       DO_IF_DEBUG(sval.type=99);					 \
